<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Tebal</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Miring</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Preferensi Manajer Jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="38"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="43"/>
        <source>Appearance</source>
        <translation>Penampilan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="48"/>
        <source>Font</source>
        <translation>Fonta</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="53"/>
        <location filename="../obconf.ui" line="114"/>
        <source>Windows</source>
        <translation>Jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="58"/>
        <source>Move &amp; Resize</source>
        <translation>Pindah &amp; Ubah Ukuran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="63"/>
        <source>Mouse</source>
        <translation>Tetikus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="68"/>
        <source>Desktops</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="73"/>
        <source>Margins</source>
        <translation>Batas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="78"/>
        <source>Dock</source>
        <translation>Dok</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="96"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Pasang tema baru...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="103"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Buat &amp;arsip tema (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="120"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Jendela mempertahankan batas ketika tidak didekorasi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="127"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>A&amp;nimasikan menjadi ikon dan memulihkan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="137"/>
        <source>Window Titles</source>
        <translation>Judul Jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="143"/>
        <source>Button order:</source>
        <translation>Urutan tombol:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="153"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Ikon jendela
L: Label jendela (Judul)
I: Ikonkan (Minimalkan)
M: Maksimalkan
C: Tutup
S: Berbayang (Gulung)
D: Selalu ada (Pada semua desktop)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="231"/>
        <source>&amp;Active window title: </source>
        <translation>Judul jendela &amp;aktif: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="241"/>
        <source>&amp;Inactive window title: </source>
        <translation>Judul jendela tidak akt&amp;if: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="251"/>
        <source>Menu &amp;header: </source>
        <translation>&amp;Header menu: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="261"/>
        <source>&amp;Menu Item: </source>
        <translation>Butir &amp;Menu: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="271"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Tampilan Pada layar yang &amp;aktif: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="281"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Tampilan Pada layar yang &amp;tak aktif: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="295"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Fokus ke je&amp;ndela baru ketika mereka muncul</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="302"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>Tem&amp;patkan jendela baru di bawah penunjuk tetikus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="309"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>Rata &amp;tengahkan jendela baru ketika mereka ditempatkan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="318"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Lebih suka menempatkan jendela baru p&amp;ada:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="329"/>
        <source>All monitors</source>
        <translation>Semua monitor</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="334"/>
        <source>The active monitor</source>
        <translation>Monitor yang aktif</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="339"/>
        <source>The monitor with the mouse</source>
        <translation>Monitor dengan tetikus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="344"/>
        <source>Primary monitor</source>
        <translation>Monitor primer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="354"/>
        <source>Primary Monitor</source>
        <translation>Monitor Primer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="360"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Monitor primer adalah tempat dimana Openbox akan meletakkan dialog, seperti misalnya yang dipakai untuk berpindah jendela.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="370"/>
        <source>Primary &amp;monitor:</source>
        <translation>&amp;Monitor primer:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="381"/>
        <source>Fixed Monitor</source>
        <translation>Monitor Tetap</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="386"/>
        <source>Active Monitor</source>
        <translation>Monitor Aktif</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="391"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Monitor Dengan Penunjuk Tetikus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="399"/>
        <source>&amp;Fixed monitor:</source>
        <translation>Monitor &amp;tetap:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="439"/>
        <source>Moving and Resizing Windows</source>
        <translation>Memindah dan Mengubah Ukuran Jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="445"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Mutakhirkan isi jendela ketika mengubah uku&amp;ran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="452"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Jarak ambang sere&amp;t:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="472"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Banyaknya resistansi terhadap &amp;jendela lain:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="492"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Banyaknya resistansi terhadap t&amp;epi layar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="512"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>L&amp;ama waktu tunggu sebelum bertukar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="532"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>Berpindah de&amp;sktop ketika memindahkan suatu jendela melampai tepi layar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>Information Dialog</source>
        <translation>Dialog Informasi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="549"/>
        <location filename="../obconf.ui" line="578"/>
        <source>Centered</source>
        <translation>Rata Tengah</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="554"/>
        <source>From left edge</source>
        <translation>Dari tepi kiri</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="559"/>
        <source>From right edge</source>
        <translation>Dari tepi kanan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="567"/>
        <source>Fixed &amp;y position:</source>
        <translation>Posisi &amp;y tetap:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="583"/>
        <source>From top edge</source>
        <translation>Dari puncak</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="588"/>
        <source>From bottom edge</source>
        <translation>Dari dasar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="596"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Posisi dialog informasi:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="606"/>
        <source>Fixed &amp;x position:</source>
        <translation>Posisi &amp;x tetap:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="616"/>
        <source>Show &amp;information dialog:</source>
        <translation>Tampilkan dialog &amp;informasi:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="641"/>
        <source>When resizing terminal windows</source>
        <translation>Ketika mengubah ukuran jendela terminal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="646"/>
        <source>Always</source>
        <translation>Selalu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="651"/>
        <source>Never</source>
        <translation>Jangan pernah</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="660"/>
        <source>Centered on the window</source>
        <translation>Di tengah jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="665"/>
        <source>Above the window</source>
        <translation>Di atas jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="670"/>
        <source>Fixed position on screen</source>
        <translation>Posisi tetap pada layar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="701"/>
        <source>Focusing Windows</source>
        <translation>Pemfokusan Jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fokuskan jendela ketika penunjuk tetikus bergerak di atas mereka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="722"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>Tun&amp;daan sebelum memfokus dan menaikkan jendela:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="742"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Pindahkan fokus di bawah tetikus ketika bertukar de&amp;sktop</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="749"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Pindahkan fok&amp;us ke bawah tetikus ketika tetikus tak bergerak</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Naikkan jendela ketika penunjuk tetikus berge&amp;rak di atasnya</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="768"/>
        <source>Titlebar</source>
        <translation>Bilah judul</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="774"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Klik ganda pada bilah &amp;judul:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="785"/>
        <source>Maximizes the window</source>
        <translation>Maksimalkan jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="790"/>
        <source>Shades the window</source>
        <translation>Membuat jendela berbayang</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="798"/>
        <source>Double click ti&amp;me:</source>
        <translation>Waktu klik ga&amp;nda:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="838"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>&amp;Tampilkan pemberitahuan ketika bertukar desktop</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="845"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>L&amp;amanya menampilkan pemberitahuan:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="868"/>
        <source>&amp;Number of desktops: </source>
        <translation>Ba&amp;nyaknya desktop: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="891"/>
        <source>&amp;Desktop names:</source>
        <translation>Nama &amp;desktop:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="905"/>
        <source>Desktop Margins</source>
        <translation>Batas Desktop</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="911"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Batas desktop adalah wilayah yang dicadangkan di tepi layar.  Jendela baru tidak akan ditempatkan di dalam sebuah batas, dan jendela yang dimaksimalkan tidak akan menutupinya.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="921"/>
        <source>Left:</source>
        <translation>Kiri:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="935"/>
        <location filename="../obconf.ui" line="956"/>
        <location filename="../obconf.ui" line="977"/>
        <location filename="../obconf.ui" line="998"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="942"/>
        <source>Top:</source>
        <translation>Atas:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="963"/>
        <source>Right:</source>
        <translation>Kanan:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="984"/>
        <source>Bottom:</source>
        <translation>Bawah:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1025"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Dok adalah wadah spesial untuk &quot;dockapps&quot;, atau aplikasi-aplikasi dok.  Ia tidak terlihat di layar sampai dockapp dijalankan.  Dockapp dapat digunakan untuk menampilkan hal-hal seperti jam, atau untuk menyediakan baki sistem.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>Position</source>
        <translation>Posisi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1053"/>
        <source>&amp;Position:</source>
        <translation>&amp;Posisi:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1067"/>
        <source>Top Left</source>
        <translation>Kiri Atas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1072"/>
        <source>Top</source>
        <translation>Atas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1077"/>
        <source>Top Right</source>
        <translation>Kanan Atas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1082"/>
        <source>Left</source>
        <translation>Kiri</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1087"/>
        <source>Right</source>
        <translation>Kanan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1092"/>
        <source>Bottom Left</source>
        <translation>Kiri Bawah</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1097"/>
        <source>Bottom</source>
        <translation>Bawah</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1102"/>
        <source>Bottom Right</source>
        <translation>Kanan Bawah</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1107"/>
        <source>Floating</source>
        <translation>Mengambang</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1121"/>
        <source>&amp;Floating position:</source>
        <translation>Posisi &amp;mengambang:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1146"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1162"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Izinkan &amp;jendela untuk ditempatkan di wilayah dok ini</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1169"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Orientasi: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1183"/>
        <source>Vertical</source>
        <translation>Vertikel</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1188"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1199"/>
        <source>Stacking</source>
        <translation>Menumpuk</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1205"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Biarkan dok di &amp;atas jendela lain</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1212"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>&amp;Izinkan dok berada di atas dan di bawah jendela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1219"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Biarkan dok di &amp;bawah jendela lain</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1229"/>
        <source>Hiding</source>
        <translation>Menyembunyikan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1235"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Jeda sebelum menyembunyikan:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1245"/>
        <source>Delay before &amp;showing:</source>
        <translation>Jeda sebelum &amp;menampilkan:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1275"/>
        <source>&amp;Hide off screen</source>
        <translation>&amp;Sembunyikan layar mati</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1306"/>
        <source>About</source>
        <translation>Tentang</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../theme.cpp" line="149"/>
        <source>Choose an Openbox theme</source>
        <translation>Pilih tema Openbox</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="65"/>
        <location filename="../desktops.cpp" line="87"/>
        <location filename="../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Desktop tanpa nama)</translation>
    </message>
    <message>
        <location filename="../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Aksi kustom</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Tentang ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Manajer preferensi untuk Openbox

Hak cipta (c) 2014-2015

Pembuat:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Program ini didasarkan pada ObConf yang dikembangkan oleh para pengembang berikut.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation type="unfinished">&quot;%2&quot; telah dipasang ke %2 {1&quot;?}</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; telah berhasil dibuat</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Tidak dapat membuat arsip tema &quot;%1&quot;.
Kesalahan berikut dilaporkan:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Tidak dapat menjalankan perintah &quot;tar&quot;: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Tidak dapat membuat direktori &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; nampaknya bukan direktori tema Openbox yang valid</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Tidak dapat memindah ke direktori &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Tidak dapat mengekstrak berkas &quot;%1&quot;.
Harap pastikan bahwa &quot;%2&quot; dapat ditulisi dan berkas tersebuat adalah arsip tema Openbox yang valid.
Kesalahan berikut dilaporkan:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Kesalahan ObConf</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Hak cipta (c) 2003-2008   Dana Jansens
Hak cipta (c) 2003        Tim Riley
Hak cipta (c) 2007        Javeed Shaikh
Hak cipta (c) 2013        Hong Jen Yee (PCMan)

Program ini SEPENUHNYA TANPA JAMINAN
Ini adalah perangkat lunak bebas, dan Anda boleh menyebarluaskannya
di bahwa kondisi tertentu. Lihat berkas COPYING untuk rinciannya.

</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Sintaks: obconf [opsi] [ARSIP.obt]

Opsi:
  --help                Menampilkan bantuan ini dan keluar
  --version             Menampilkan versi dan keluar
  --install ARSIP.obt   Memasang arsip tema yang diberikan dan memilihnya
  --archive TEMA        Membuat suatu arsip tema dari direktori tema yang diberikan
  --config-file BERKAS  Menyatakan path ke berkas konfig yang akan dipakai
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install memerlukan suatu argumen
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive memerlukan suatu argumen
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file memerlukan suatu argumen
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="223"/>
        <location filename="../obconf-qt.cpp" line="238"/>
        <source>Error</source>
        <translation>Kesalahan</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="224"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Gagal memuat rc.xml. Mungkin Anda gagal memasang Openbox dengan benar.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="236"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Kesalahan saat mengurai berkas konfigurasi Openbox.  Berkas konfigurasi Anda bukan XML yang valid.

Pesan: %1</translation>
    </message>
</context>
</TS>
